# -*- coding: utf-8 -*-
# Copyright (c) Ezcad Development Team. All Rights Reserved.
"""
Entry point to the application
This __main__.py file is for start by Python -m ezcad.
"""

from ezcad.app.main import main
main()
